function outputsignal = maf(inputsignal,filterwindow)
% Zero-phase unweighted moving average filter function
% (using convolution equivalent of matlab's filtfilt() )
%
% Author: DJ van Gerwen
% Created: 2016 june 5

% Process inputs
x = inputsignal(:); % Enforce column vector
fw = filterwindow; % Number of samples [-]

% Filter kernel
k = ones(1,fw)/fw; % Convolution kernel (sums to 1) [-]

% Forward-backward filtering using convolution
kk = conv(k,k); % Cascaded kernel (triangular, length 2*fw-1) [-]
nkk = length(kk); % Length of cascaded kernel
xc = [x(1)*ones((nkk-1)/2,1); x; x(end)*ones((nkk-1)/2,1)]; % Extrapolate boundaries by  (nkk-1)/2 samples to alleviate boundary problems
xcconv = conv(xc,kk); % Convolve signal with cascaded kernel
outputsignal = xcconv(nkk:end-nkk+1); % Select the part without the extrapolated boundaries

end