function show_AIN(L)

% Read AIN channels by polling and updating a plot in a continuous loop
% NOTE: this does not use Labjack streaming
%
% TODO: implement a record button instead of using the running history
%
% Author: DJ van Gerwen
% Created: 2016 june 5

close all

% Force labjack configuration (to make sure e.g. range is set correctly)
L.configure_labjack

% Initialize figure and lines
namefun = @(freq) sprintf(['AIN channel(s) [%u' repmat(', %u',1,...
    L.number_of_AIN-1) '] @ %.0fHz'],L.AIN_list,freq);
hfig = figure('color','white','numbertitle','off','name',namefun(nan));
cmp = colormap(lines);
for ch = 1:L.number_of_AIN
    hline(ch) = line(nan,nan,'color',cmp(ch,:));
end
tmp = L.AIN_names; % TEMP
haxes = gca;
set(haxes,'ylim',max(L.AIN_range_V)*[-1 1],'box','on','xminortick','off')
grid on
xlabel 'time [s]'
ylabel 'AIN [V]'
hleg = legend(hline,L.AIN_names,'location','northwest'); %,'interpreter','none');

% Update data using simple calls to labjack
ts = tic; % Sample time reference [s]
tu = tic; % Update reference [s]
tf = tic; % Frequency reference [s]
samples = 0; % Sample counter [-]
refreshrate = 10; % [Hz]
historywindow = 10000; % Number of samples in history [-]
displaywindow = 1000; % Part of history that is displayed [-]
AIN_V = nan(L.number_of_AIN,historywindow);
time_s = nan(1,historywindow);
avgfreq = nan;
while isvalid(hfig)
    
    % Reset time histories every x samples
    if ~samples || samples > historywindow-1
        if ~samples
            samples = 0;
        else
            AIN_V(:,1:displaywindow)  = ...
                AIN_V(:,historywindow+(1-displaywindow:0));
            time_s(:,1:displaywindow) = ...
                time_s(:,historywindow+(1-displaywindow:0));
            samples = displaywindow;
        end
        AIN_V(:,samples+1:historywindow) = nan;
        time_s(samples+1:historywindow) = nan;
        disp('...history reset...')
    end
    
    
    % Update time histories
    samples = samples+1;
    time_s(samples) = toc(ts);
    AIN_V(:,samples) = L.AIN_state_V;
    % NOTE: The latter polls the labjack via the get method for the AIN_state_V property.
    
    % Update frequency
    if ~mod(samples,displaywindow) % Refresh lines every x samples
        avgfreq = displaywindow/toc(tf); % Average window frequency [Hz]
        tf = tic;
    end
    
    % Update axes and lines
    displayindex = max(1,samples-displaywindow+1):samples;
    if toc(tu) > 1/refreshrate
        if isvalid(hfig)
            set(hfig,'name',namefun(avgfreq))
        end
        for ch = 1:L.number_of_AIN
            if isvalid(hfig)
                set(hline(ch),'xdata',time_s(displayindex),...
                    'ydata',AIN_V(ch,displayindex));
            end
        end
        if isvalid(hfig)
            set(haxes,'xlim',time_s(displayindex([1 end])))
        end
        drawnow
        tu = tic; % Reset reference time
    end
end
disp('Stopped')
end