function update_PWM_duty_cycle(L)
% Update PWM duty cycle
%
% Author: DJ van Gerwen
% Created: 2016 june 5

% The duty cycle represents a percentage of the roll value, and
% is sent to the T7 or UE9 expressed in clock counts. NOTE:
% PWM_duty_cycle is a dependent property and automatically
% takes the limits into account

switch L.device_type
    case 'T7'
        for i = 1:length(L.PWM_list)
            names{i} = sprintf('DIO%u_EF_CONFIG_A', L.PWM_list(i));
        end
        if exist('names','var')
            values = round(L.PWM_duty_cycle * L.PWM_clock_roll_value);
            LabJack.LJM.eWriteNames(L.lj_handle, length(names), ...
                names, values, 0);
        end
    case 'UE9'
        values = round(L.PWM_duty_cycle); % TODO: make units consistent with T7
        for i = 1:length(values)
            L.UDobject.ePut(L.lj_handle, LabJack.LabJackUD.IO.PUT_TIMER_VALUE, ...
                L.PWM_list(i), values(i), 0); % Set PWM duty cycle on selected channel
        end
        
    otherwise
        warning('update_PWM_duty_cycle not implemented for U3')
end

end