function [h] = PillowGUI(figGUI,h)

%% This m-file defines GUI-elements for pillow force measurements on Lowlands
% Author: dr.ir. Arjo J. Loeve
% E-mail: a.j.loeve@tudelft.nl
% Date: 2016AUG15-17.45

%% Define some css colors
h.cssCForce = [0 191/255 191/255];
h.cssCTime = [250/255 150/255 255/255];

%% Define message label background colors
h.cssCBackMesClear = h.cssCForce; %[140/255 230/255 255/255]; % Blueish for start
h.MesClear='Do not push yet. Wait for start...';
h.cssCBackMesHarder = [230/255 140/255 255/255]; % Purple for harder
h.MesHarder='PUSH HARDER';
h.cssCBackMesKeep = [112/255 212/255 72/255]; % Greenish for hold
h.MesKeep='keep pushing...';
h.cssCBackMesPaused = [255/255 102/255 0]; % Orange for paused
h.MesPaused='...paused...';
h.cssCBackMesDone = h.cssCBackMesClear; % Blueish for done
h.MesDone='Completed! You may stop pushing. Thanks!';
h.cssCBackMesAbort = [255/255 0 0]; % Blueish for done
h.MesAbort='Aborted. ENTER REASON IN NOTES FIELD!';

%% Define constants for layout
intS = 1/34; % Spacer distance as fraction between objects
cowIn = 0.33; % Column width as fraction for area with input and control elements
cowOut = 1-cowIn; % Column width as fraction for area with output elements
xlOut = 2*intS; % Left edge of Out elements
ytOut = 1-(1*intS); % Top edge of Out elements
ybOut = 8*intS;
xlIn = cowOut+2*intS; % Left edge of In elements
ytIn = ytOut; % Top edge of In elements
%PillowGU

% Define heights, widths, left and bottom of all In elements.
% TOGETHER WITH SPACINGS, THE HEIGHTS SHOULD ADD UP TO 1
wIn = cowIn-3*intS; % Width of single column In elements
wOut = cowOut-xlOut; % Width of Out elements area minus left margin
wEditOut = 6*intS; % Width of output edit boxes
hEditSL = 2*intS; % Height of single line edit boxes
hEditSLOut = 3*intS; % Height of single line edit Out boxes
hStart = 6*intS; % Height of Start button
hStop = 4*intS; % Height of Stop button
hNext = hEditSLOut; % Height of Next button
hLbl = 0.9*intS; % Height of labels
hMes = 2*intS; % Height of message label on graph

% Define basic FONT (F) colors, sizes and styles
cssFColorBtn = [1 1 1];
cssFColorLbl = [1 1 1];
cssFColorEdt = [0 0 0];
cssFColorEdtOut = [1 1 1];
cssFColorXes = 'none';%[1 1 1]; %'none'; 
cssFColorMes = [1 1 1];
cssFWeightBtn = 'bold';
cssFWeightLbl = 'bold';
cssFWeightEdt = 'normal';
cssFWeightXes = 'normal';
cssFWeightMes = 'bold';
cssFSizeLbl = 14;
cssFSizeBtn = 18;
cssFSizeEdt = 14;
cssFSizeEdtOut = 20;
cssFSizeXes = 12;
cssFSizeMes = 26;
cssFont = 'Helonia';
cssFAlign = 'left';
cssFAlignEdtOut = 'center';
cssFAlignMes = 'center';

% Define other colors that are used more than once
cssCBack = [0 0 0]; % General background color
cssCBackEdtOut = [0.2 0.2 0.2]; % Background color for Out edit boxes
cssCBackEdtIn = [1 1 1]; % Background color for In edit boxes

% %% Make main screen
% h.figMAIN = uipanel('Parent',figMAIN,... % Main panel
%     'BackgroundColor',cssCBack,'Position',[0 0 1 1]);

%% Make In elements
% Make buttons
h.Start = uicontrol(figGUI,'Style','pushbutton','String','Start',...
    'Units','normalized','ForegroundColor',cssFColorBtn,...
    'BackgroundColor',[126/255 211/255 0],'Position',[xlIn ytIn-12*intS wIn hStart],...
    'FontName',cssFont,'FontSize',cssFSizeBtn,'FontWeight', cssFWeightBtn,...
    'Enable', 'off');
h.Stop = uicontrol(figGUI,'Style','pushbutton','String','Terminate',...
    'Units','normalized','ForegroundColor',cssFColorBtn,...
    'BackgroundColor',[1 0 0],'Position',[xlIn ytIn-16*intS wIn hStop],...
    'FontName',cssFont,'FontSize',cssFSizeBtn,'FontWeight', cssFWeightBtn,...
    'Enable', 'off');
h.Next = uicontrol(figGUI,'Style','pushbutton','String','NEXT Measurement',...
    'Units','normalized','ForegroundColor',cssFColorBtn,...
    'BackgroundColor',[0 102/255 102/255],'Position',[xlIn 2*intS wIn hNext],...
    'FontName',cssFont,'FontSize',cssFSizeBtn,'FontWeight', cssFWeightBtn,...
    'Enable', 'off');

% Make edit boxes
h.edtSubj = uicontrol(figGUI,'Style','edit','String','',...
    'Units','normalized','ForegroundColor',cssFColorEdt,...
    'BackgroundColor',cssCBackEdtIn,'Position',[xlIn ytIn-3*intS wIn hEditSL],...
    'FontName',cssFont,'FontSize',cssFSizeEdt,'FontWeight', cssFWeightEdt);
h.edtNotes = uicontrol(figGUI,'Style','edit','String','',...
    'Units','normalized','ForegroundColor',cssFColorEdt,...
    'BackgroundColor',cssCBackEdtIn,'Position',[xlIn ybOut wIn (ytIn-19*intS)-ybOut],...
    'FontName',cssFont,'FontSize',cssFSizeEdt,'FontWeight', cssFWeightEdt,...
    'HorizontalAlignment','left','Enable','off','Max',3);

% Make labels in separate structure, as they are static
lbl.Subj = uicontrol(figGUI,'Style','text','String','1) Scan badge for subject nr.',...
    'Units','normalized','ForegroundColor',cssFColorLbl,...
    'BackgroundColor',cssCBack,'Position',[xlIn ytIn-0.9*intS wIn hLbl],...
    'FontName',cssFont,'FontSize',cssFSizeLbl,'FontWeight', cssFWeightLbl,...
    'HorizontalAlignment',cssFAlign);
lbl.Controls = uicontrol(figGUI,'Style','text','String','2) Measurement controls',...
    'Units','normalized','ForegroundColor',cssFColorLbl,...
    'BackgroundColor',cssCBack,'Position',[xlIn ytIn-6.1*intS wIn hLbl],...
    'FontName',cssFont,'FontSize',cssFSizeLbl,'FontWeight', cssFWeightLbl,...
    'HorizontalAlignment',cssFAlign);
lbl.Notes = uicontrol(figGUI,'Style','text','String','3) Notes',...
    'Units','normalized','ForegroundColor',cssFColorLbl,...
    'BackgroundColor',cssCBack,'Position',[xlIn ytIn-19.1*intS wIn hLbl],...
    'FontName',cssFont,'FontSize',cssFSizeLbl,'FontWeight', cssFWeightLbl,...
    'HorizontalAlignment',cssFAlign);
lbl.Next = uicontrol(figGUI,'Style','text','String','4) Save and start new',...
    'Units','normalized','ForegroundColor',cssFColorLbl,...
    'BackgroundColor',cssCBack,'Position',[xlIn 5.1*intS wIn hLbl],...
    'FontName',cssFont,'FontSize',cssFSizeLbl,'FontWeight', cssFWeightLbl,...
    'HorizontalAlignment',cssFAlign);

%% Make Out elements
% Make axes
h.xesForce = axes('Units','normalized',...
    'Position',[xlOut ybOut wOut ytOut-ybOut-intS],...
    'NextPlot','add','Xgrid','on','Ygrid','on',...
    'GridAlpha',0.3,...
    'FontName',cssFont,'FontSize',cssFSizeXes,...
    'FontWeight', cssFWeightXes,'Color',cssFColorXes,...
    'XColor', h.cssCTime, 'YColor', h.cssCForce);
h.xesForce.XLabel.String = 'Time [s]';
h.xesForce.YLabel.String = 'Force [N]';
h.xesForce.Title.String = 'Force vs. Time';
h.xesForce.Title.Color = cssFColorLbl;
h.xesForce.Title.FontSize = cssFSizeLbl;
h.xesForce.YLim = [0 h.MaxExpF];
h.xesForce.XLim = [0 h.SampleT*(h.PlotLength-1)];

% Make axes containing background image. Not in h, because static
lbl.xesLogo = axes('Units','normalized',...
    'Position',[xlOut+intS ybOut wOut-2*intS ytOut-ybOut-intS],'Color',[1 1 1]);
uistack(lbl.xesLogo,'bottom');
% Show logo image in background axes
imshow('PillowBGinv.gif');
%Hide axes and axes labels etc.
axis(lbl.xesLogo,'off');

% % Make axes containing background color. Not in h, because static
% lbl.xesBG = axes('Units','normalized',...
%     'Position',[xlOut ybOut wOut ytOut-ybOut-intS],'Color',[1 1 1],...
%     'NextPlot','add',...
%     'XColor', 'none', 'YColor', 'none');
% uistack(lbl.xesBG,'bottom');
% axis(lbl.xesBG,'off');

% Make message label on graph
h.lblMes = uicontrol(figGUI,'Style','text','String',h.MesClear,...
    'Units','normalized','ForegroundColor',cssFColorMes,...
    'BackgroundColor',h.cssCBackMesClear,'Position',[xlOut ytOut-2*hMes wOut hMes],...
    'FontName',cssFont,'FontSize',cssFSizeMes,'FontWeight', cssFWeightMes,...
    'HorizontalAlignment',cssFAlignMes);

% Make edit boxes
h.edtVolt = uicontrol(figGUI,'Style','edit','String','0',...
    'Units','normalized','ForegroundColor',cssFColorEdtOut,...
    'BackgroundColor',cssCBackEdtOut,'Position',[xlOut 2*intS wEditOut hEditSLOut],...
    'FontName',cssFont,'FontSize',cssFSizeEdtOut,'FontWeight', cssFWeightEdt,...
    'HorizontalAlignment',cssFAlignEdtOut,'Enable','inactive');
h.edtForce = uicontrol(figGUI,'Style','edit','String','0',...
    'Units','normalized','ForegroundColor',cssFColorEdtOut,...
    'BackgroundColor',cssCBackEdtOut,'Position',[xlOut+wEditOut+intS 2*intS wEditOut hEditSLOut],...
    'FontName',cssFont,'FontSize',cssFSizeEdtOut,'FontWeight', cssFWeightEdt,...
    'HorizontalAlignment',cssFAlignEdtOut,'Enable','inactive');
h.edtSmotherProg = uicontrol(figGUI,'Style','edit','String','0',...
    'Units','normalized','ForegroundColor',cssFColorEdtOut,...
    'BackgroundColor',cssCBackEdtOut,'Position',[xlOut+2*wEditOut+2*intS 2*intS wEditOut hEditSLOut],...
    'FontName',cssFont,'FontSize',cssFSizeEdtOut,'FontWeight', cssFWeightEdt,...
    'HorizontalAlignment',cssFAlignEdtOut,'Enable','inactive');

% Make labels in separate structure, as they are static
lbl.edtVolt = uicontrol(figGUI,'Style','text','String','Signal [V]',...
    'Units','normalized','ForegroundColor',cssFColorLbl,...
    'BackgroundColor',cssCBack,'Position',[xlOut 5.1*intS wEditOut hLbl],...
    'FontName',cssFont,'FontSize',cssFSizeLbl,'FontWeight', cssFWeightLbl,...
    'HorizontalAlignment',cssFAlignEdtOut);
lbl.edtForce = uicontrol(figGUI,'Style','text','String','Force [N]',...
    'Units','normalized','ForegroundColor',cssFColorLbl,...
    'BackgroundColor',cssCBack,'Position',[xlOut+wEditOut+intS 5.1*intS wEditOut hLbl],...
    'FontName',cssFont,'FontSize',cssFSizeLbl,'FontWeight', cssFWeightLbl,...
    'HorizontalAlignment',cssFAlignEdtOut);
lbl.edtSmotherProg = uicontrol(figGUI,'Style','text','String','Progress [%]',...
    'Units','normalized','ForegroundColor',cssFColorLbl,...
    'BackgroundColor',cssCBack,'Position',[xlOut+2*wEditOut+2*intS 5.1*intS wEditOut hLbl],...
    'FontName',cssFont,'FontSize',cssFSizeLbl,'FontWeight', cssFWeightLbl,...
    'HorizontalAlignment',cssFAlignEdtOut);
end

